@@ -123,4 +123,4 @@ class Solo(Process):
 
             # Write it out
             fname = inspect.currentframe().f_code.co_name
-            self.write(algorithm=fname, counter=ctr, source=summation)
+            self.write(algorithm=fname, counter=ctr, source=newAudio)
